Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(494)

Unified Diff: net/quic/test_tools/quic_crypto_server_config_peer.h

Issue 2681793002: Landing Recent QUIC changes until 5:30 PM, Feb 3, 2017 UTC-5 (Closed)
Patch Set: sync and rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/test_tools/fake_proof_source.cc ('k') | net/quic/test_tools/quic_crypto_server_config_peer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/test_tools/quic_crypto_server_config_peer.h
diff --git a/net/quic/test_tools/quic_crypto_server_config_peer.h b/net/quic/test_tools/quic_crypto_server_config_peer.h
index 310be87bf264e5d48970d7e660b5f86b9d2cbb89..facde4ef8c9bc8e587ebd2a99b2a958c9f5f9210 100644
--- a/net/quic/test_tools/quic_crypto_server_config_peer.h
+++ b/net/quic/test_tools/quic_crypto_server_config_peer.h
@@ -60,20 +60,20 @@ class QuicCryptoServerConfigPeer {
std::string NewServerNonce(QuicRandom* rand, QuicWallTime now) const;
// CheckConfigs compares the state of the Configs in |server_config_| to the
// description given as arguments. The arguments are given as
// nullptr-terminated pairs. The first of each pair is the server config ID of
// a Config. The second is a boolean describing whether the config is the
// primary. For example:
// CheckConfigs(nullptr); // checks that no Configs are loaded.
//
// // Checks that exactly three Configs are loaded with the given IDs and
// // status.
// CheckConfigs(
- // "id1", false,
- // "id2", true,
- // "id3", false,
- // nullptr);
- void CheckConfigs(const char* server_config_id1, ...);
+ // {{"id1", false},
+ // {"id2", true},
+ // {"id3", false}});
+ void CheckConfigs(
+ std::vector<std::pair<ServerConfigID, bool>> expected_ids_and_status);
// ConfigsDebug returns a string that contains debugging information about
// the set of Configs loaded in |server_config_| and their status.
« no previous file with comments | « net/quic/test_tools/fake_proof_source.cc ('k') | net/quic/test_tools/quic_crypto_server_config_peer.cc » ('j') | no next file with comments »
@@ -60,20 +60,20 @@ class QuicCryptoServerConfigPeer {
std::string NewServerNonce(QuicRandom* rand, QuicWallTime now) const;
// CheckConfigs compares the state of the Configs in |server_config_| to the
- // description given as arguments. The arguments are given as
- // nullptr-terminated pairs. The first of each pair is the server config ID of
- // a Config. The second is a boolean describing whether the config is the
- // primary. For example:
- // CheckConfigs(nullptr); // checks that no Configs are loaded.
+ // description given as arguments.
+ // The first of each pair is the server config ID of a Config. The second is a
+ // boolean describing whether the config is the primary. For example:
+ // CheckConfigs(std::vector<std::pair<ServerConfigID, bool>>()); // checks
+ // that no Configs are loaded.
//
// // Checks that exactly three Configs are loaded with the given IDs and

Powered by Google App Engine
This is Rietveld 408576698